"""
Kini - A secure command-line password manager
"""

__version__ = "1.0.0"
__author__ = "Sagar Paul"
__email__ = "paul.sagar@yahoo.com"

from .password_manager import PasswordManager

__all__ = ["PasswordManager"]
